Enum async_dnssd::BrowsedFlag
[−]
[src]
#[repr(u8)]pub enum BrowsedFlag { MoreComing, Add, }
Flags for BrowseResult
Variants
MoreComingIndicates at least one more result is pending in the queue. If not set there still might be more results coming in the future.
AddIndicates the result is new. If not set indicates the result was removed.
See kDNSServiceFlagsAdd.