Enum async_dnssd::Error
[−]
[src]
pub enum Error {
KnownError(DNSServiceError),
UnknownError(i32),
}API Error
Variants
KnownError(DNSServiceError)If error code used some recognized name
UnknownError(i32)Unrecognized error codes
Methods
impl Error[src]
fn from(value: i32) -> Result<(), Error>
Check if a raw error code represents an error, and convert it
accordingly. (Not all codes are treated as an error, including
0).