Enum async_dnssd::RegisterFlag
[−]
[src]
#[repr(u8)]pub enum RegisterFlag { NoAutoRename, Shared, Unique, }
Flags used to register service
Variants
NoAutoRenameIndicates a name conflict should not get handled automatically.
Indicates there might me multiple records with the given name, type and class.
UniqueIndicates the records with the given name, type and class is unique.