Struct async_dnssd::BrowseResult
[−]
[src]
pub struct BrowseResult {
pub flags: BrowsedFlags,
pub interface: Interface,
pub service_name: String,
pub reg_type: String,
pub domain: String,
}Browse result
Fields
flags: BrowsedFlags
Flags indicating whether the service was added or removed and whether there are more pending results.
interface: Interface
Interface the service was found on.
service_name: String
Name of the service.
reg_type: String
Type of the service
domain: String
Domain the service was found in
Methods
impl BrowseResult[src]
fn resolve(&self, handle: &Handle) -> Result<Resolve>
Resolve browse result.
Should check before whether result has the Add flag, as
otherwise it probably won't find anything.