Struct async_dnssd::EnumeratedFlags
[−]
[src]
pub struct EnumeratedFlags(_);
Set of EnumeratedFlags
Flags and sets can be combined with bitor (|), and bitand (&)
can be used to test whether a flag is part of a set.
Methods
impl EnumeratedFlags[src]
fn none() -> Self
Construct empty set of flags.