Struct async_dnssd::QueriedRecordFlags
[−]
[src]
pub struct QueriedRecordFlags(_);
Set of QueriedRecordFlags
Flags and sets can be combined with bitor (|), and bitand (&)
can be used to test whether a flag is part of a set.
Methods
impl QueriedRecordFlags[src]
fn none() -> Self
Construct empty set of flags.